#include<stdio.h>
#include<stdlib.h>

#include "mol_system.h"
#include "topology_gromos96.h"

main(int argc, char *argv[]) {

  static struct g96topology topology; /* This must be static otherwise the 
					 stack does not hold it */
  static struct mol_system g96conformation; /* Same as above */
  char g96topology_filename[256],gromacstopology_filename[256];
  char g96_filename[256],gsf_filename[256];
  int i;
  double boxsize_x,boxsize_y,boxsize_z;
  int boxread,velocitiesread,no_solvent_molecules;

  /* Templates */
  void usage();
  void readg96topology(char *,struct g96topology *);
  void read_g96_file(char *,
		     struct mol_system *,
		     double *,
		     double *,
		     double *,
		     int *);
  void read_g96_velocities(char *,
			   struct mol_system *,
			   int *);
  void write_gromacs_topology(char *,struct g96topology *,int );
  void write_gsf_file(char *,
		      struct mol_system *,
		      double ,
		      double ,
		      double ,
		      int ,
		      int );
  void calculate_no_solvent_molecules(struct mol_system *,
				      int *);


  /* Write program capabilities if the number of arguments do not match */
  if (argc!=3 && argc!=5) {
    usage();
  } else {
    usage();
    /* Parse inputs */
    strcpy(g96topology_filename,argv[1]);
    strcpy(gromacstopology_filename,argv[2]);
    if (argc==5) {
      strcpy(g96_filename,argv[3]);
      strcpy(gsf_filename,argv[4]);
    }

    no_solvent_molecules=0;

    if (argc==5) {
      /* Read the GROMOS96 formatted conformation file */
      read_g96_file(g96_filename,
		    &g96conformation,
		    &boxsize_x,
		    &boxsize_y,
		    &boxsize_z,
		    &boxread);

      /* Try to read velocities from conformation file */
      read_g96_velocities(g96_filename,
			  &g96conformation,
			  &velocitiesread);
      if (velocitiesread==1) {
	printf("Velocities were found in the GROMOS96 conformation file.\n");
	printf("These velocities will be written to the GROMACS conformation file.\n\n");
      }


      /* Write the GROMOS87 (and GROMACS) formatted conformation file */
      write_gsf_file(gsf_filename,
		     &g96conformation,
		     boxsize_x,
		     boxsize_y,
		     boxsize_z,
		     boxread,
		     velocitiesread);
      if (boxread==1) {
	printf("A box record was found in the GROMOS96 conformation file.\n");
	printf("The sizes of the box were written to the GROMACS conformation");
	printf(" file,\nassuming that a rectangular box is present. If this ");
	printf("is not the case, change this\ninformation manually.\n\n");
      }

      /* Find the number of solvent molecules present in the conformation */
      calculate_no_solvent_molecules(&g96conformation,&no_solvent_molecules);
      printf("%d solvent molecules were found in the conformation file.\n",
	     no_solvent_molecules);
      printf("This number of solvent molecules (water is assumed) were \n");
      printf("included in the topology file. Check if this is correct.\n");
    }

    /* Read GROMOS96 formatted topology */
    readg96topology(g96topology_filename,&topology);


    /* Write GROMACS formatted topology */
    write_gromacs_topology(gromacstopology_filename,
			   &topology,
			   no_solvent_molecules);

  }

  return 0;

} /* Main */


void usage() {
    printf("\nConvert GROMOS96 topologies and conformation files to their ");
    printf("GROMACS equivalents \n\n");
    printf("Claudio M. Soares (claudio@itqb.unl.pt), ITQB-UNL Oeiras 2002-08-30, ");
    printf("version 1.0\n\n");
    printf("convertgromos2gromacs usage:\n\n");
    printf("convertgromos2gromacs gromos96topologyfile gromacstopologyfile ");
    printf("[gromos96conformationfile gromacsconformationfile ]\n\n\n");
} /* usage */
