/* READS A G96 (GROMOS 96) FILE LOOKING FOR VELOCITIES. IF THEY ARE       */
/* PRESENT, THEY ARE READ INTO A STRUCTURE, BEING PLACED IN THE PROP      */
/* FIELDS OF THIS STRUCTURE                                               */
/*                                                                        */
/*   Claudio M. Soares, ITQB-UNL Oeiras 2002-08-30                        */
/*------------------------------------------------------------------------*/

#include<stdio.h>
#include<string.h>
#include<stdlib.h>

#include "mol_system.h"

void read_g96_velocities(char *filename,       /* The filename to be read */
		   struct mol_system *aux,     /* The molecular structure */
		   int *velocitiesread)        /* 1 if velocities were    */
                                               /* read and 0 otherwise    */
{

	FILE *ifile;
	char string[256],string_aux[256];
	char string_aux3[256];
	int i,contcycle,count;
	
	/* Templates */
	int fread_until_end_of_line_no_comment(FILE *,char * );
	int fread_until_token(FILE *,char * );
	void copy_substring_to_string(char *,char *,int,int);
	void right_adjust_string(char *);

	/* Velocities weren't read yet */
	*velocitiesread=0;

	if ( (ifile=fopen(filename, "r")) == NULL ) {
		printf("Input file %s can not be open.\n",filename);
		exit(2);
	} else {
		
	  /* Read until record VELOCITY is found */
	  if (fread_until_token(ifile,"VELOCITY")==1) {
	    /* Velocities are present in the file */
	    *velocitiesread=1;

	    /* Read them now */
	    count=0;
	    contcycle=1;
	    while (contcycle==1) {
	      fread_until_end_of_line_no_comment(ifile,string);
	      copy_substring_to_string(string,string_aux,1,3);
	      if (strcmp(string_aux,"END")==0) {
		/* END record found */
		contcycle=0;
	      } else {

		/* Read VX VY and VZ velocities  */
		copy_substring_to_string(string,string_aux,25,39);
		aux->prop[count][0]=atof(string_aux);
		copy_substring_to_string(string,string_aux,40,54);
		aux->prop[count][1]=atof(string_aux);
		copy_substring_to_string(string,string_aux,55,69);
		aux->prop[count][2]=atof(string_aux);
		++count;

	      }

	    }

	  }

	  fclose(ifile);
	}

	
} /* read_g96_velocities */



