#include<stdio.h>
#include<string.h>
#include<stdlib.h>


/************************************************************************/
/* Some string handling routines used in this program                   */
/*                                                                      */
/* Claudio M. Soares, ITQB Oeiras 2000                                  */
/************************************************************************/










/*************************************************************************/
/* Read lines of the open file until a specific token is found           */
/* If the token is found, the next line is the line AFTER the line where */
/* the token has been found and the function returns 1. If the token is  */
/* not found and the end of file is reached, the function returns 0      */
/*                                                                       */
/* Claudio M. Soares, ITQB Oeiras, 2000                                  */
/*************************************************************************/
int fread_until_token(FILE *ifile,char *token) {
  
  int size_of_token;
  int found_token=0;
  int notfound_end_of_file=1;
  char line[256],substring[256];
  
  /* Templates */
  int fread_until_end_of_line(FILE *,char *);
  void copy_substring_to_string(char *,char *,int ,int );

  /* Determines the size of the token */
  size_of_token=strlen(token);

  /* Read lines until the token is found in the first characters */
  while (found_token==0 && notfound_end_of_file==1) {
    notfound_end_of_file=fread_until_end_of_line(ifile,line);
    if (notfound_end_of_file==1) {
      copy_substring_to_string(line,substring,0,size_of_token);
      if (strcmp(substring,token)==0) {
	/* The token has been found */
	found_token=1;
      }
    }
  }

  /* Verify if end of file was found before the token was found */
  if (notfound_end_of_file==0) {
    return 0;
  } else {
    return 1;
  }


} /* fread_until_token */



/* Reads one line from a file. It returns the line if sucessful and 1. */
/* If the end of file is reached it returns 0                          */
int fread_until_end_of_line(FILE *ifile,char *line )
{
  char c;
  int found_end_of_line=0;
  int found_end_of_file=0;

  while( (found_end_of_line==0) && (found_end_of_file==0) ) {
    c=fgetc(ifile);
    if (c==EOF) {  /* Verify end of file */
      found_end_of_file=1;
    } else {
      if (c!='\n') {  /* Verify end of line */
	*line=c;
	++line;
      } else {
	found_end_of_line=1;
      }
    }
  }
  *line='\0';  /* Place a termination character in the string */

  /* If end of file was reached before an end of line return 0 */
  if (found_end_of_file==1) {
    return 0;
  } else {
    return 1;
  }

} /* fread_until_end_of_line */


/* Reads one line from a file. This line cannot have a comment at its  */
/* beginning (comment being "#"). If this is the case, the next line   */
/* is read. It returns the line if sucessful and 1.                    */
/* If the end of file is reached it returns 0                          */
int fread_until_end_of_line_no_comment(FILE *ifile,char *line )
{
  int notfound_end_of_file=1;
  int found_line_no_comment=0;

  /* Templates */
  int fread_until_end_of_line(FILE *,char *);
  void copy_substring_to_string(char *,char *,int ,int );

  while (found_line_no_comment==0 && notfound_end_of_file==1){
    notfound_end_of_file=fread_until_end_of_line(ifile,line);
    if (line[0]!='#') {
      /* This is a non-comment line */
      found_line_no_comment=1;
    }
  } 
  


  /* If end of file was reached before a non-comment line return 0 */
  if (notfound_end_of_file==0) {
    return 0;
  } else {
    return 1;
  }

} /* fread_until_end_of_line_no_comment */



/* Copies a substring defined by initial and final indices to a 
   terminated string. The indices start at ONE and NOT at ZERO       */
void copy_substring_to_string(char *string,char *substring,
                 int initial,int final) {
  int i;
  
  for (i=1;i<=final;i++) {
    if (i<initial) {
      ++string;
    } else {
      *substring=*string;
      ++string;
      ++substring;
    }
  }
  *substring='\0';
	
} /* copy_substring_to_string */





/* Right adjust a string                            */
void right_adjust_string(char *str)
{
  char *aux,*aux1,*aux2;
  int count,i;
  
  /* Work with aux */
  aux=malloc(sizeof(char)*256);
  aux2=malloc(sizeof(char)*256);
  aux1=aux;
  strcpy(aux,str);
  
  /* Find end of string */
  while (*aux!='\0')
    ++aux;
    
  /* Move end of string */
  --aux;
  count=0;
  while (*aux==' ')
  {
    --aux;
    ++count;
  }
  ++aux;
  *aux='\0';
  
  /* Add deleted space at the beginning */
  aux=aux1;
  strcpy(aux2," ");
  for (i=1;i<=count;++i)
  {
    strcat(aux2,aux);
    strcpy(aux,aux2);
    strcpy(aux2," ");
  }
  
 
  /* Copy to the original string */
  strcpy(str,aux);
  
  /* Free memory */
  free(aux1);
  free(aux2);
 
} /* right_adjust_string */



/* Left adjust a string */
void left_adjust_string(char *str)
{
  char *aux,*aux1;
  int count,i;
  
  /* Work with aux */
  aux=malloc(sizeof(char)*256);
  aux1=aux;
  strcpy(aux,str);
  
  count=0;
  while (*aux==' ')
  {
    ++aux;
    ++count;
  }
  
  /* Add the spaces from the beginning to the end of string */
  for (i=1;i<=count;++i)
    strcat(aux," ");
  
  /* Copy to the original string */
  strcpy(str,aux);
  
  /* Free memory */
  free(aux1);
 
} /* left_adjust_string */
