/**************************************************************

   Claudio M. Soares, ITQB Oeiras 2000, Revision 2002-08-30
 **************************************************************/

/* The maximum number of atoms in the molecular topology file */
#define MAXATOMSTOPOLOGY 100000

/* The maximum number of residues */
#define MAXAA2 6000

#define MAXATOMTYPESTOPOLOGY 100
#define MAXEXCLUSIONS 54


/* The maximum number of bond types */
#define MAXNBT 100

/* Maximum number of bonds with heteroatoms */
#define MAXBON 30000

/* Maximum number of bonds involving H-atoms */
#define MAXBNH 10800

/* The maximum number of bondangle types */
#define MAXTTY 250

/* Maximum number of bondangles with heteroatoms */
#define MAXTHE 36000

/* Maximum number of bondangles involving H-atoms */
#define MXQHEH 15600

/* The maximum number of improper dihedral types */
#define MAXQTY 80

/* Maximum number of improper dihedrals with heteroatoms */
#define MAXQHI 12000

/* Maximum number of improper dihedrals involving H-atoms */
#define MAXHIH 6000

/* The maximum number of dihedral types */
#define MAXPTY 60

/* Maximum number of dihedrals with heteroatoms */
#define MAXPHI 21000

/* Maximum number of dihedrals involving H-atoms */
#define MXPHIH 6000



struct g96topology {
  int no_of_atoms;
  char title[256];
  int no_of_residues;
  char residues[MAXAA2][6];    /* The names of the residues in the system */
                               /* These are the residues, ordered */
  char atom_name[MAXATOMSTOPOLOGY][6];    /* The elements of this array with */
  char residue_name[MAXATOMSTOPOLOGY][6]; /* a fixed size of five            */
  int atom_number[MAXATOMSTOPOLOGY];
  int residue_number[MAXATOMSTOPOLOGY];
  int atom_iac[MAXATOMSTOPOLOGY];   /* Integer atom code of atom */
  double atom_charge[MAXATOMSTOPOLOGY]; /* The partial charge of the atom */
  double atom_mass[MAXATOMSTOPOLOGY]; /* The mass of the atom */
  int atom_charge_group_code[MAXATOMSTOPOLOGY]; /* Charge group code of the
						   current atom. If the atom 
						   is the end of a charge 
						   group, then this code will 
						   be 1,otherwise it will be 
						   zero  */
  int atom_ine[MAXATOMSTOPOLOGY]; /* The number of excluded atoms of the 
				     current atom */
  int atom_ine14[MAXATOMSTOPOLOGY]; /* The number of 1-4 excluded atoms of the
				       current atom */
  int atom_excl[MAXATOMSTOPOLOGY][MAXEXCLUSIONS]; /* Numbers of the excluded
						     atoms of the current
						     atom  */
  int atom_excl_1_4[MAXATOMSTOPOLOGY][MAXEXCLUSIONS]; /* Numbers of the 1-4
							 excluded atoms of
							 the current atom */
  int nratt; /* Number of van der Waals atom types */
  char atom_type_name[MAXATOMTYPESTOPOLOGY][6];  /* Names of the atom types */

  /* The four arrays below contain the Lennard-Jones parameters corresponding
     to the atom types in the form [type-1,type-1] */
  double c12[MAXATOMTYPESTOPOLOGY][MAXATOMTYPESTOPOLOGY]; /* Normal Lennard-
							     Jones parameters
							     C12 */
  double c6[MAXATOMTYPESTOPOLOGY][MAXATOMTYPESTOPOLOGY];  /* Normal Lennard-
							     Jones parameters
							     C6 */
  double cs12[MAXATOMTYPESTOPOLOGY][MAXATOMTYPESTOPOLOGY];  /* 1-4 Lennard-
							       Jones parameters
							       C12 */
  double cs6[MAXATOMTYPESTOPOLOGY][MAXATOMTYPESTOPOLOGY];   /* 1-4 Lennard-
							       Jones parameters
							       C6 */
  int lj_indices[MAXATOMTYPESTOPOLOGY][MAXATOMTYPESTOPOLOGY][2]; /* The IACs
								 that corres-
								 pond to speci-
								 fic interac-
								 tion of the
								 four arrays
								 above */
  int nbty;           /* The number of bond types                       */
  double cb[MAXNBT];  /* The force constant  of the specified bond      */
  double b0[MAXNBT];  /* The equilibrium distance of the specified bond */
  int nbon;                  /* The nr of bonds between non-hydrogen atoms */
  int ib[MAXBON],jb[MAXBON]; /* Non-hydrogen atoms i,j forming a bond      */
  int icb[MAXBON];           /* The type of bond formed between atoms i,j  */
  int nbonh;                   /* The nr of bonds involving one H-atoms      */
  int ibh[MAXBNH],jbh[MAXBNH]; /* Atoms i,j forming a bond                   */
  int icbh[MAXBNH];            /* The type of bond formed between atoms i,j  */

  int ntty;            /* The number of bond angle types                     */
  double ct[MAXTTY];   /* The force constant of the specified bondangle      */
  double t0[MAXTTY];   /* The equilibrium bond angle                         */
  int nthe;            /* The nr of bondangles between non-hydrogen atoms    */
  int it[MAXTHE],jt[MAXTHE],kt[MAXTHE]; /* Atoms i,j,k forming a bondangle   */
  int ict[MAXTHE];                      /* The type of bondangle             */
  int ntheh;            /* The nr of bondangles involving one hydrogen atom  */
  int ith[MXQHEH],jth[MXQHEH],kth[MXQHEH]; /* Atoms i,j,k forming a bondangle*/
  int icth[MXQHEH];                      /* The type of bondangle            */

  int nqty;            /* The number of improper dihedral types              */
  double cq[MAXQTY];   /* The force constant of the specified improper dih.  */
  double q0[MAXQTY];   /* The equilibrium improper dihedral                  */
  int nqhi;            /* The nr of improper dih. between non-hydrogen atoms */
  int iq[MAXQHI],jq[MAXQHI],kq[MAXQHI],lq[MAXQHI]; /* Atoms i,j,k,l forming  */
                                                   /* the improper dih.      */
  int icq[MAXQHI];                                 /* The type of the        */
                                                   /* improper dihedral      */
  int nqhih;           /* The nr of improper dih. involving one hydrogen atom*/
  int iqh[MAXHIH],jqh[MAXHIH],kqh[MAXHIH],lqh[MAXHIH]; /* Atoms i,j,k,l      */
                                                       /* forming the        */
                                                       /* the improper dih.  */
  int icqh[MAXHIH];                                 /* The type of the       */
                                                    /* improper dihedral     */

  int npty;            /* The number of dihedral types                       */
  int np[MAXPTY];      /* Multiplicity of the dihedral type                  */
  double cp[MAXPTY];   /* Force constant of the dihedral type                */
  double pd[MAXPTY];   /* Cosine of the phase shift of the dihedral type     */
  int nphi;            /* Number of dih. not involving H-atoms               */
  int ip[MAXPHI],jp[MAXPHI],kp[MAXPHI],lp[MAXPHI]; /* i,j,k,l atoms of the   */
                                                   /* dihedral               */
  int icp[MAXPHI];                                 /* Type of the dihedral   */
  int nphih;           /* Number of dih. involving at least one H-atom       */
  int iph[MXPHIH],jph[MXPHIH],kph[MXPHIH],lph[MXPHIH]; /* i,j,k,l atoms of   */
                                                       /* the dihedral       */
  int icph[MXPHIH];                                    /* Type of the dih.   */



}; /* g96 topology struct */


