/* WRITES A GSF FILE                                                      */
/* The atom positions are assumed to be in nm                             */
/* No processing is done in residue names, atom names, etc, so it is      */
/* assumed that the format of the data is the GROMOS format               */
/*                                                                        */
/*                                                                        */
/*   Claudio Soares, ITQB Oeiras 1996, Revised 2002-08-30                 */
/*------------------------------------------------------------------------*/

#include<stdio.h>
#include<stdlib.h>

#include "mol_system.h"

void write_gsf_file(char *filename,
		    struct mol_system *a,
		    double boxsize_x,
		    double boxsize_y,
		    double boxsize_z,
		    int write_box,     /* When equal to 1 means that a box */
                                       /* record will be written           */
		    int write_velocities) /* When equal to 1 velocities    */
                                          /* will be written               */
{

	FILE *ofile;
	int i;
       
	/* Templates */
	void right_adjust_string(char *);
	void left_adjust_string(char *);

	if ( (ofile=fopen(filename, "w")) == NULL )
	{
		printf("Output file %s can not be open.\n",filename);
		exit(2);
	}
	else
	{

	     /* Write title */
	     fprintf(ofile,"%s\n",a->title);

	     /* Write number of atoms */
	     fprintf(ofile,"%5d\n",a->no_of_atoms);

	     /* Write for each atom ... */
             for (i=0;i<a->no_of_atoms;++i)
             {
	       left_adjust_string(a->resname[i]);
	       right_adjust_string(a->aname[i]);
	       if (write_velocities==1) {
		 fprintf(ofile,"%5d%5s%5s%5d%8.3f%8.3f%8.3f%8.4f%8.4f%8.4f\n",
			 a->resnumber[i],
			 a->resname[i],
			 a->aname[i],
			 a->anumber[i],
			 a->conf[i][0],
			 a->conf[i][1],
			 a->conf[i][2],
			 a->prop[i][0],
			 a->prop[i][1],
			 a->prop[i][2]);
	       } else {
		 fprintf(ofile,"%5d%5s%5s%5d%8.3f%8.3f%8.3f\n",
			 a->resnumber[i],
			 a->resname[i],
			 a->aname[i],
			 a->anumber[i],
			 a->conf[i][0],
			 a->conf[i][1],
			 a->conf[i][2]);
	       }
             }

	     if (write_box==1) {
	       /* Write a box record to the output */
	       fprintf(ofile,"%10.5f%10.5f%10.5f\n",
		       boxsize_x,
		       boxsize_y,
		       boxsize_z);
	     }

	     fclose(ofile);
	}
	
	
}
